package org.jeecg.modules.ctop.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.shiro.SecurityUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.modules.ctop.entity.ByteDanceUserOrientationTemplate;
import org.jeecg.modules.ctop.mapper.ByteDanceUserOrientationTemplateMapper;
import org.jeecg.modules.ctop.service.IByteDanceUserOrientationTemplateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * @Description: 今日头条受众模板信息
 * @Author: jeecg-boot
 * @Date: 2019-07-23
 * @Version: V1.0
 */
@Service
public class ByteDanceUserOrientationTemplateServiceImpl extends ServiceImpl<ByteDanceUserOrientationTemplateMapper, ByteDanceUserOrientationTemplate> implements IByteDanceUserOrientationTemplateService {
    @Autowired
    private ByteDanceUserOrientationTemplateMapper templateMapper;

    @Override
    public Map<String, Object> insertTemplate(JSONObject template) {
        Map<String, Object> resultMap = new HashMap<>();
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        ByteDanceUserOrientationTemplate orientationTemplate = new ByteDanceUserOrientationTemplate(user.getId(), template);
        this.saveOrUpdate(orientationTemplate);
        resultMap.put("success", true);
        resultMap.put("message", "投放目标模板保存成功");
        return resultMap;
    }

    @Override
    public Result<IPage<ByteDanceUserOrientationTemplate>> getList(ByteDanceUserOrientationTemplate template, Integer pageNo, Integer pageSize, HttpServletRequest req) {
        Result<IPage<ByteDanceUserOrientationTemplate>> result = new Result<>();
        QueryWrapper<ByteDanceUserOrientationTemplate> queryWrapper = QueryGenerator.initQueryWrapper(template, req.getParameterMap());
        LoginUser user = (LoginUser) SecurityUtils.getSubject().getPrincipal();
        String advertiserId = user.getId();
        queryWrapper.eq("advertiser_id", advertiserId).orderByDesc("create_time");
        Page<ByteDanceUserOrientationTemplate> page = new Page<>(pageNo, pageSize);
        IPage<ByteDanceUserOrientationTemplate> pageList = this.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }
}
