package org.jeecg;

import cn.com.ctop.common.utils.OSSUtils;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.jeecg.common.util.ResultMapUtils;
import org.jeecg.common.util.StatusCode;
import org.jeecg.common.util.jsonschema.JsonschemaUtil;
import org.jeecg.modules.ctop.entity.ByteDanceUserOrientationTemplate;
import org.jeecg.modules.ctop.entity.BytedanceAreaInfo;
import org.jeecg.modules.ctop.entity.BytedanceInterestCategory;
import org.jeecg.modules.ctop.entity.CtopOauthToken;
import org.jeecg.modules.ctop.mapper.ByteDanceUserOrientationTemplateMapper;
import org.jeecg.modules.ctop.mapper.BytedanceAreaInfoMapper;
import org.jeecg.modules.ctop.mapper.BytedanceInterestCategoryMapper;
import org.jeecg.modules.ctop.service.IByteDanceAdvertiserDataService;
import org.jeecg.modules.ctop.service.ICreateInternalService;
import org.jeecg.modules.ctop.service.ICtopOauthTokenService;
import org.jeecg.modules.ctop.service.IReportService;
import org.jeecg.modules.demo.mock.MockController;
import org.jeecg.modules.demo.test.mapper.JeecgDemoMapper;
import org.jeecg.modules.demo.test.service.IJeecgDemoService;
import org.jeecg.modules.system.service.ISysDataLogService;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import javax.annotation.Resource;
import java.io.File;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@RunWith(SpringRunner.class)
@SpringBootTest
public class SampleTest {

    @Resource
    private JeecgDemoMapper jeecgDemoMapper;
    @Resource
    private IJeecgDemoService jeecgDemoService;
    @Resource
    private ISysDataLogService sysDataLogService;
    @Resource
    private MockController mock;

    @Autowired
    private IReportService reportService;

    @Test
    public void loadCustomerData() {
        Map<String, Object> result = new HashMap<>();
        String csvPath = "D:\\工作文件\\360借条\\借条后台数据实时.csv";
        reportService.insertCustomerInfo(csvPath, "utf8");
        ResultMapUtils.setResultMap(result, StatusCode.COMMON_SUCCESS.getCode());
    }

    @Test
    public void loadPlatformData() {
        Map<String, Object> result = new HashMap<>();
        String csvPath4 = "D:\\工作文件\\360借条\\快手后台数据-户4.csv";
        reportService.insertPlatformInfo(csvPath4, "GBK", 4L);
        String csvPath1 = "D:\\工作文件\\360借条\\快手后台数据-户1.csv";
        reportService.insertPlatformInfo(csvPath1, "GBK", 1L);
    }

    @Autowired
    private ICreateInternalService createInternalService;

    @Test
    public void testLogin() {
        Map<String, Object> map = createInternalService.checkAccountPassword("dcd_ad@bytedance.com", "typdDCD@2018");
        System.out.println(map.toString());
    }

    @Test
    public void testFileType() {
        File file = new File("D:\\工作文件\\360借条\\快手后台数据-户1.csv");
        System.out.println(file);
    }

    @Test
    public void testFileUpload() {
        OSSUtils.uploadObject2Oss(new File("D:\\upload\\excel\\template.xlsx"));
    }

    @Test
    public void testNg() {
        JSONObject json = new JSONObject();
        System.err.println(json);
        createInternalService.createInternal(json);
    }

    @Autowired
    private BytedanceAreaInfoMapper areaInfoMapper;
    @Autowired
    private BytedanceInterestCategoryMapper interestCategoryMapper;

    @Test
    public void setCategoryData() {
        String path = "D:\\工作文件\\头条批量\\data_20190222\\ad_tag.json";
        String jsonString = JsonschemaUtil.readJsonFile(path);
        JSONObject data = JSONObject.parseObject(jsonString);
        JSONArray tagArray = data.getJSONArray("adtags");
        tagArray.forEach(tag -> {
            JSONObject getTag = (JSONObject) tag;
            String pcode = getTag.getString("value");
            String plabel = getTag.getString("label");
            BytedanceInterestCategory category = new BytedanceInterestCategory();
            category.setCode(pcode);
            category.setName(plabel);
            category.setParentCode("0");
            category.setLevel(1);
            category.setCreateTime(new Date());
            category.setUpdateTime(new Date());
            interestCategoryMapper.insert(category);
            JSONArray children = getTag.getJSONArray("subTags");
            children.forEach(child -> {
                JSONObject getchild = (JSONObject) child;
                String code = getchild.getString("value");
                String label = getchild.getString("label");
                BytedanceInterestCategory childCategory = new BytedanceInterestCategory();
                childCategory.setCode(code);
                childCategory.setName(label);
                childCategory.setParentCode(pcode);
                childCategory.setLevel(2);
                childCategory.setCreateTime(new Date());
                childCategory.setUpdateTime(new Date());
                interestCategoryMapper.insert(childCategory);
            });
        });
    }

    @Autowired
    private ICtopOauthTokenService tokenService;
    @Autowired
    private ByteDanceUserOrientationTemplateMapper userOrientationTemplateMapper;
    @Autowired
    private IByteDanceAdvertiserDataService advertiserDataService;

    @Test
    public void testEditPlan() throws Exception {
        String accountId = "74099510334";
        Long userOrientationId = 5L;
        Long adId = 1643004580559934L;
        //修改用户定向
        ByteDanceUserOrientationTemplate template = userOrientationTemplateMapper.selectById(userOrientationId);
        if (null != template) {
            CtopOauthToken token = tokenService.getOauthTokenByAccountId(accountId);
            if (null != token) {
                //获取modify_time
                Thread.sleep(5000L);
                advertiserDataService.getAdvertiserPlan(accountId, adId + "");
                advertiserDataService.updateAd(token, adId, template);
            }
        }
    }
    @Test
    public void setJSONFile() {
        String path = "C:\\Users\\宋英豪\\Downloads\\data_20190222\\city.json";
        String jsonString = JsonschemaUtil.readJsonFile(path);
        JSONObject data = JSONObject.parseObject(jsonString);
        data.forEach((k, v) -> {
            JSONObject getData = data.getJSONObject(k);
            BytedanceAreaInfo areaInfo = new BytedanceAreaInfo();
            Integer level = getData.getInteger("level");
            Long id = getData.getLong("id");
            String name = getData.getString("name");
            System.out.println(name);
            String parent = getData.getString("parent");
            areaInfo.setId(id);
            areaInfo.setLevel(level);
            String code = id + "";
            if (level == 1) {
                areaInfo.setParentCode(parent);
                areaInfo.setCode(code);
            } else if (level == 2) {
                areaInfo.setParentCode(code.substring(0, 2));
                areaInfo.setCode(code.substring(0, 4));
            } else {
                areaInfo.setParentCode(code.substring(0, 4));
                areaInfo.setCode(code);
            }
            areaInfo.setName(name);
            areaInfo.setCreateTime(new Date());
            areaInfo.setUpdateTime(new Date());
            areaInfoMapper.insert(areaInfo);
        });
    }
}
